.. image:: ../../imgs/ooipy_banner2.png
  :width: 700
  :alt: OOIPY Logo
  :align: left

OOIPY Usage Guide
=================
This section of the documentation is under development and will be updated
in the future. In the meantime, please see the demo.ipynb located in our
`Github Repository <https://github.com/ooipy/ooipy>`_.

